-- main.applescript
-- DistributeTasksViaPooch

--  Created by Dean Dauger on 6/2/05.
--  Copyright 2005 Dauger Research, Inc. All rights reserved.

on run {input, parameters}
	set caseCount to 4 -- change this number to whatever you want
	
	repeat with caseNumber from 1 to caseCount
		
		submitCase(caseNumber, input)
		
	end repeat
	
	return input
end run

on createCaseFolder(caseNumber, docList)
	
	set inputFile to 1
	set baseFolder to GetParentPath(first item of docList)
	set caseFolderName to (("case" & caseNumber) as text)
	set caseFolder to {}
	
	tell application "Finder"
		try
			set caseFolder to make new folder at baseFolder with properties {name:caseFolderName}
		end try
		
		set caseFolder to folder caseFolderName in baseFolder
		
		try
			set inputFile to make new file at caseFolder with properties {name:"input"}
		end try
		
		set inputFile to file "input" in caseFolder
		
		set fileRef to (open for access file (inputFile as text) with write permission)
		write (caseNumber as text) & return & return to fileRef
		
		close access fileRef
		
		set dupDocList to duplicate docList to caseFolder replacing yes
		
		set outDocList to {inputFile as alias}
		
		repeat with thisFileItem in docList
			
			set outDocList to ((outDocList) & {(file (name of thisFileItem) in caseFolder) as alias})
			
		end repeat
		
		return (outDocList)
		
	end tell
	
end createCaseFolder

on launchCase(caseNumber, thisDocList)
	
	tell application "Pooch App"
		activate
		
		set j to make new job -- remember, the default job includes the node the script is running on
		
		open thisDocList
		
		delete node list of j
		
		--	make new node at j with properties {name:"remote node", address:"10.0.1.9"}
		
		set tasks per computer of j to 1
		set launch failure queues job to yes
		set retrieve output of j to yes
		
		set automatically acquire nodes of j to yes
		set node acquire count of j to 1
		set acquire nodes includes starting node of j to no
		
		set Unix arguments of j to (caseNumber as string)
		
		launch j
		
	end tell
	
end launchCase

on submitCase(caseNumber, docList)
	
	log "Submitting case " & caseNumber
	
	set thisDocList to docList
	
	set thisDocList to createCaseFolder(caseNumber, thisDocList)
	launchCase(caseNumber, thisDocList)
	
	delay 3 -- AppleScript often needs time to rest
	
end submitCase

on GetParentPath(theFile)
	tell application "Finder" to return container of theFile
end GetParentPath
